import { Command as CommanderCommand } from "commander";
import { ConfigKey } from "../constants";
import { ProjectorConfig, ServiceCollection } from "../models";
import { Link } from "../models/general/link";
export declare type ActionHandler<T> = (serviceCollection: ServiceCollection, options: T, config: ProjectorConfig) => void | Promise<void>;
/**
 * Configuration for interactive options
 */
export interface OptionInteractiveConfig<T = string> {
    /**
     * Short flag name (e.g. -n, -r, -t)
     */
    shortName: string;
    /**
     * Long flag name (e.g. --name, --file-path)
     */
    longName: string;
    /**
     * Question to prompt users for correct value
     */
    prompt?: string;
    /**
     * Description of flag
     */
    description?: string;
    /**
     * Config key to load value and skip question if exists
     */
    configKey?: ConfigKey;
    /**
     * Options to choose from
     */
    choices?: T[];
    /**
     * Default value of option
     */
    defaultValue?: T;
}
/**
 * Command extension class
 */
export declare class Command<TOptions = any> extends CommanderCommand {
    private actions;
    private commandOptions;
    constructor();
    initialize(initializeAction: () => void): Command<TOptions>;
    optionInteractive(optionConfig: OptionInteractiveConfig): Command<TOptions>;
    /**
     * Gets a variable name from a long option name
     *
     * @param {string} longName Long variable name `--my-variable-name`
     * @returns {string} camelCasedVariableName (e.g. myVariableName)
     */
    private getVariableName;
    addAction(actionHandler: ActionHandler<TOptions>): Command<TOptions>;
    printHelp(): Command<TOptions>;
    asciiArt(message: string): Command<TOptions>;
    addLinkCommands(links: Link[]): Command<TOptions>;
    addPhoneTree(): Command<TOptions>;
    toMarkdownDoc(parentCommandPath?: string): string;
    toTableOfContents(linkPrefix?: string, parentIndentation?: string, parentCommandPath?: string): string;
}
